backtracks package
==================

Module contents
---------------

.. automodule:: backtracks
   :members:
   :undoc-members:
   :show-inheritance:




backtracks.backtracks module
----------------------------

.. automodule:: backtracks.backtracks
   :members:
   :undoc-members:
   :show-inheritance:

backtracks.plotting module
--------------------------

.. automodule:: backtracks.plotting
   :members:
   :undoc-members:
   :show-inheritance:

backtracks.utils module
-----------------------

.. automodule:: backtracks.utils
   :members:
   :undoc-members:
   :show-inheritance:

